@@ -10,9 +10,10 @@ ver=${ver%/}
 
 src=linux-${ver}
 dst=gentoo-headers-base-${ver}
+distdir=$(portageq distdir)
 
 if [ ! -d ${src} ] ; then
-	for srcdir in . "$(portageq distdir)" /usr/portage/distfiles ; do
+	for srcdir in . "${distdir}" /usr/portage/distfiles ; do
 		for ext in bz2 xz ; do
 			srctar=${srcdir}/${src}.tar.${ext}
 			if [ -e ${srctar} ] ; then
@@ -23,7 +24,7 @@ if [ ! -d ${src} ] ; then
 	done
 fi
 if [ ! -d ${src} ] ; then
-	wget https://www.kernel.org/pub/linux/kernel/v${ver:0:1}.x/linux-${ver}.tar.xz -P /usr/portage/distfiles/
+	wget https://www.kernel.org/pub/linux/kernel/v${ver:0:1}.x/linux-${ver}.tar.xz -P "${distdir}"
 	exec "$0" "$@"
 fi
 
@@ -44,6 +45,9 @@ cp -r \
 	${src}/scripts/unifdef.c \
 	${src}/scripts/*.{sh,pl} \
 	${dst}/scripts/
+if [[ -f ${src}/scripts/subarch.include ]]; then
+	cp ${src}/scripts/subarch.include ${dst}/scripts/
+fi
 mkdir -p ${dst}/scripts/basic
 printf '#!/bin/sh\nexit 0' > ${dst}/scripts/basic/fixdep
 chmod a+rx ${dst}/scripts/basic/fixdep
@@ -68,12 +72,12 @@ for a in ${arches} ; do
 		done
 	fi
 done
-# handle x86 unique cruft
+# handle x86 unique headers
 if [[ -e ${src}/arch/x86/entry/syscalls ]] ; then
 	mkdir -p ${dst}/arch/x86/entry
 	cp -r ${src}/arch/x86/entry/syscalls ${dst}/arch/x86/entry/
 fi
-# mips has some stupid unique bs
+# mips has some unique headers as well
 if [[ -e ${src}/arch/mips/Kbuild.platforms ]] ; then
 	for f in "${src}"/arch/mips/*/Platform ; do
 		f=${f#${src}}
@@ -85,6 +89,11 @@ if [[ -d ${src}/arch/mips/boot/tools ]] ; then
 	mkdir -p ${dst}/arch/mips/boot
 	cp -r ${src}/arch/mips/boot/tools ${dst}/arch/mips/boot/
 fi
+# s390 has special sauce starting from 4.16
+if [[ -d ${src}/arch/s390/kernel/syscalls ]] ; then
+	mkdir -p ${dst}/arch/s390/kernel
+	cp -r ${src}/arch/s390/kernel/syscalls ${dst}/arch/s390/kernel/
+fi
 find ${dst}/ -name .gitignore -delete
 
 cp README.ripped-headers rip-headers.sh ${dst}/
